@@ -48,7 +48,7 @@ has schema_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
   predicate=>'has_schema_class', env_prefix=>ENV_PREFIX, cmd_aliases => 'S');
 
 has target_dir => (traits => [ 'Getopt', 'ENV' ],
-  is => 'ro', isa=> AbsolutePath, coerce => 1,
+  is => 'ro', isa=> 'Str',
   predicate=>'has_target_dir', env_prefix=>ENV_PREFIX, cmd_aliases => 'dir');
 
 has sandbox_dir => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa=> 'Str',
